# Виды электронных подписей

## Общие сведения

В России в электронном документообороте можно использовать три вида подписи: простую (ПЭП), неквалифицированную (НЭП) и квалифицированную (КЭП) электронные подписи. 

По способу хранения ЭП делятся на облачные и на специальном носителе (токенах).

Облачная электронная подпись позволяет подписывать документы СЭД и КЭДО с любого устройства, без привязки к рабочему месту. В Lexema-ECM можно работать как со сторонними облачными электронными подписями (ЭП), так и с собственными облачными неквалифицированными подписями (УНЭП). В систему встроен сервис для выпуска УНЭП.

## Простая электронная подпись, или ПЭП

Простая подпись — это знакомые всем коды доступа из СМС, коды на скретч-картах, пары "логин-пароль" в личных кабинетах на сайтах и в электронной почте. Простая подпись создается средствами информационной системы, в которой ее используют, и подтверждает, что электронную подпись создал конкретный человек.  

### Где используется простая электронная подпись?

Простая электронная подпись чаще всего применяется при банковских операциях, а также для аутентификации в информационных системах, для получения госуслуг, для заверения документов внутри корпоративного электронного документооборота (далее — ЭДО).

Простую электронную подпись нельзя использовать при подписании электронных документов или в информационной системе, которые содержат гостайну.

### Юридическая сила ПЭП

Простая подпись приравнивается к собственноручной, если это регламентирует отдельный нормативно-правовой акт или между участниками ЭДО заключено соглашение, где прописаны:

- правила, по которым подписанта определяют по его простой электронной подписи;
- обязанность пользователя соблюдать конфиденциальность закрытой части ключа ПЭП (например, пароля в паре "логин-пароль" или СМС-кода, присланного на телефон).

Во многих информационных системах пользователь должен сначала подтвердить свою личность во время визита к оператору системы, чтобы его ПЭП в будущем имела юридическую силу. Например, для получения подтвержденной учетной записи на портале Госуслуг, нужно лично прийти в один из центров регистрации с документом, удостоверяющим личность.

## Неквалифицированная электронная подпись, или НЭП {#НЭП}

Усиленная неквалифицированная электронная подпись (далее — НЭП) создается с помощью программ криптошифрования с использованием закрытого ключа электронной подписи. НЭП идентифицирует личность владельца, а также позволяет проверить, вносили ли в файл изменения после его отправки.  

Человек получает в удостоверяющем центре два ключа электронной подписи: закрытый и открытый. Закрытый ключ хранится на специальном ключевом носителе с пин-кодом или в компьютере пользователя — он известен только владельцу и его нужно держать в тайне. С помощью закрытого ключа владелец генерирует электронные подписи, которыми подписывает документы.

Открытый ключ электронной подписи доступен всем, с кем его обладатель ведет ЭДО. Он связан с закрытым ключом и позволяет всем получателям подписанного документа проверить подлинность ЭП.

То, что открытый ключ принадлежит владельцу закрытого ключа, прописывается в сертификате электронной подписи. Сертификат также выдается удостоверяющим центром. Но при использовании НЭП сертификат можно не создавать. Требования к структуре неквалифицированного сертификата не установлены в федеральном законе № 63-ФЗ "Об электронной подписи". 

### Где используется неквалифицированная электронная подпись?

НЭП можно использовать для внутреннего ЭДО, если стороны предварительно договорились об этом.

### Юридическая сила НЭП

Участникам ЭДО нужно соблюдать дополнительные условия, чтобы электронные документы, заверенные НЭП, считались равнозначными бумажным с собственноручной подписью. Сторонам нужно обязательно заключить между собой соглашение о правилах использования НЭП и взаимном признании ее юридической силы.

## Квалифицированная электронная подпись или КЭП

Усиленная квалифицированная электронная подпись — самый регламентированный государством вид подписи. Так же, как и НЭП, она  создается с помощью криптографических алгоритмов и базируется на инфраструктуре открытых ключей, но отличается от НЭП в следующем:

- Обязательно имеет квалифицированный сертификат в бумажном или электронном виде, структура которого определена приказом ФСБ России № 795 от 27.12.2011.
- Программное обеспечение для работы с КЭП сертифицировано ФСБ России.
- Выдавать КЭП может только удостоверяющий центр, который аккредитован Минкомсвязи России.

### Где используется квалифицированная электронная подпись?

КЭП нужна, чтобы сдавать отчетность в контролирующие органы, участвовать в качестве поставщика и заказчика в электронных торгах, работать с государственными информационными системами, обмениваться формализованными документами с ФНС, вести электронный документооборот внутри компании или с ее внешними контрагентами.

### Юридическая сила КЭП

КЭП — это подпись, которая придает документам юридическую силу без дополнительных условий.  Если организации ведут ЭДО, подписывая документы КЭП,  их юридическая сила признается автоматически согласно федеральному закону № 63-ФЗ "Об электронной подписи".

КЭП полностью приравнивается к ручной ("мокрой") подписи.

## Сводная таблица {#table}

Вид подписи | Что из себя представляет | Какие кадровые документы можно подписать? | Зона действия ЭП и риски
------------|--------------------------|-------------------------------------------|-------------------------
ПЭП | Логин-пароль | Расчетные листки, табель учета рабочего времени | Документы, имеющие силу только внутри ИС. Риски минимальные
НЭП | Заказывается в удостоверяющих центрах или создается силами собственных IT-специалистов | Все, кроме документов по увольнению сотрудников | Любые документы, действующие внутри компании. Риск утери НЭП влечет максимум подписание вместо сотрудника только кадрового документа
КЭП | Заказывается в аккредитованных удостоверяющих центрах | Все | Любые документы, включая финансовые и юридические. Утеря КЭП может нанести серьезный финансовый и репутационный ущерб

## Сводная таблица по применимости видов подписи к некоторым типам документов

Роль | ПЭП | НЭП | КЭП
-|-----|-----|----
Работник | Применимо к не указанным в разделе по НЭП документам, в отношении которых трудовым законодательством и иными нормативными правовыми актами, содержащими нормы трудового права, предусмотрено их оформление на бумажном носителе и (или) ознакомление с ними работника или лица, поступающего на работу, в письменной форме, в том числе под роспись, **за исключением**: трудовых книжек и формируемых в соответствии с трудовым законодательством в электронном виде сведений о трудовой деятельности работников, акта о несчастном случае на производстве по установленной форме, приказа (распоряжения) об увольнении работника, документов, подтверждающих прохождение работником инструктажей по охране труда, в том числе лично подписываемых работником. | При заключении трудового договора, договора о материальной ответственности, ученического договора, договора на получение образования без отрыва или с отрывом от работы, при внесении в них изменений, при подписании согласия на перевод, заявления об увольнении, отзыве заявления об увольнении, а также при ознакомлении с уведомлением об изменении определенных сторонами условий трудового договора, приказом (распоряжением) о применении дисциплинарного взыскания | Применимо к документам, в отношении которых трудовым законодательством и иными нормативными правовыми актами, содержащими нормы трудового права, предусмотрено их оформление на бумажном носителе и (или) ознакомление с ними работника или лица, поступающего на работу, в письменной форме, в том числе под роспись, **за исключением**: трудовых книжек и формируемых в соответствии с трудовым законодательством в электронном виде сведений о трудовой деятельности работников, акта о несчастном случае на производстве по установленной форме, приказа (распоряжения) об увольнении работника, документов, подтверждающих прохождение работником инструктажей по охране труда, в том числе лично подписываемых работником.
Работодатель | - | Применимо к не указанным в разделе по КЭП документам, в отношении которых трудовым законодательством и иными нормативными правовыми актами, содержащими нормы трудового права, предусмотрено их оформление на бумажном носителе и (или) ознакомление с ними работника или лица, поступающего на работу, в письменной форме, в том числе под роспись, **за исключением**: трудовых книжек и формируемых в соответствии с трудовым законодательством в электронном виде сведений о трудовой деятельности работников, акта о несчастном случае на производстве по установленной форме, приказа (распоряжения) об увольнении работника, документов, подтверждающих прохождение работником инструктажей по охране труда, в том числе лично подписываемых работником. | При заключении трудовых договоров, договоров о материальной ответственности, ученических договоров, договоров на получение образования без отрыва или с отрывом от работы, при внесении в них изменений, а также при подписании приказа (распоряжения) о применении дисциплинарного взыскания, уведомлении об изменении определенных сторонами условий трудового договора

> Данные приведены на основании [Федерального закона от 22.11.2021 № 377-ФЗ "О внесении изменений в Трудовой кодекс Российской Федерации"](http://publication.pravo.gov.ru/Document/View/0001202111220001)